import { EncodableArray } from '@zoltu/ethereum-abi-encoder';
import { IOffChainTransaction } from '@zoltu/ethereum-types';
export declare const NotEthereumBrowserErrorMessage = "Your browser does not appear to be Ethereum enabled.";
export interface BrowserDependenciesOptions {
    readonly gasLimitProvider?: (transaction: Omit<IOffChainTransaction, 'gasPrice'> & {
        gasPrice?: bigint;
    }) => Promise<bigint>;
    readonly gasPriceInAttoethProvider?: () => Promise<bigint>;
}
export declare class BrowserDependencies {
    private readonly fallbackDependencies?;
    private readonly options;
    constructor(fallbackDependencies?: Dependencies | undefined, options?: BrowserDependenciesOptions);
    readonly call: (to: bigint, methodSignature: string, parameters: EncodableArray, value: bigint) => Promise<Uint8Array>;
    readonly submitTransaction: (to: bigint, methodSignature: string, parameters: EncodableArray, value: bigint) => Promise<TransactionReceipt>;
    readonly request: (method: string, params: unknown) => Promise<unknown>;
    readonly isEthereumBrowser: () => boolean;
    readonly getPrimaryAccount: () => Promise<bigint | undefined>;
    private readonly makeRequest;
    private readonly ethAccounts;
    private readonly ethCall;
    private readonly ethEstimateGas;
    private readonly ethGasPrice;
    private readonly ethGetTransactionReceipt;
    private readonly ethGetTransactionCount;
    private readonly ethSendTransaction;
}
export declare class JsonRpcError extends Error {
    readonly code: number;
    readonly data?: unknown;
    constructor(code: number, message: string, data?: unknown);
}
declare global {
    interface Ethereum1193 {
        request(options: {
            readonly method: string;
            readonly params?: unknown;
        }): Promise<unknown>;
    }
    interface EthereumLegacy {
        sendAsync(options: {
            jsonrpc: '2.0';
            id: number | string | null;
            method: string;
            params: readonly unknown[];
        }, callback: (error: unknown, response: unknown) => void): void;
    }
    interface EthereumEnableable {
        enable(): Promise<readonly string[]>;
    }
    interface Window {
        ethereum?: (Ethereum1193 | EthereumLegacy) & ({} | EthereumEnableable);
        web3?: {
            currentProvider: EthereumLegacy;
        };
    }
}
export interface Log {
    readonly topics: ReadonlyArray<bigint>;
    readonly data: Uint8Array;
}
export interface TransactionReceipt {
    readonly status: boolean;
    readonly logs: Iterable<Log>;
}
export interface Dependencies {
    call(address: bigint, methodSignature: string, methodParameters: EncodableArray, value: bigint): Promise<Uint8Array>;
    submitTransaction(address: bigint, methodSignature: string, methodParameters: EncodableArray, value: bigint): Promise<TransactionReceipt>;
}
